@@ -2,8 +2,10 @@ package App::IndonesianHolidayUtils;
 
 use 5.010001;
 
-our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-01-13'; # DATE
+our $DIST = 'App-IndonesianHolidayUtils'; # DIST
+our $VERSION = '0.05'; # VERSION
 
 1;
 # ABSTRACT: List Indonesian holidays
@@ -20,7 +22,7 @@ App::IndonesianHolidayUtils - List Indonesian holidays
 
 =head1 VERSION
 
-This document describes version 0.04 of App::IndonesianHolidayUtils (from Perl distribution App-IndonesianHolidayUtils), released on 2016-01-18.
+This document describes version 0.05 of App::IndonesianHolidayUtils (from Perl distribution App-IndonesianHolidayUtils), released on 2021-01-13.
 
 =head1 SYNOPSIS
 
@@ -28,6 +30,12 @@ This distribution contains several CLI's related to Indonesian holidays:
 
 =over
 
+=item * L<is-id-holiday>
+
+=item * L<list-id-holidays>
+
+=item * L<list-id-workdays>
+
 =back
 
 =head1 HOMEPAGE
@@ -40,7 +48,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-IndonesianHolida
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IndonesianHolidayUtils>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-IndonesianHolidayUtils/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -56,7 +64,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
